/* Various routines to perform simple actions.
 *
 * Epona (c) 2000 PegSoft
 * Contact us at epona@pegirc.com
 *
 * This program is free but copyrighted software; see the file COPYING for
 * details.
 *
 * Based on the original code of Services by Andy Church.
 *
 */

#include "services.h"

/*************************************************************************/

void change_user_mode(User *u, char *mode) 
{
	char *av[2];
	
	if (!u || !mode) return;
	
	av[0] = sstrdup(u->nick);
	av[1] = sstrdup(mode);
	send_cmd(NULL, "SVSMODE %s %s", u->nick, mode);
	do_umode(u->nick, 2, av);
	free(av[1]);
	free(av[0]);	
}

/*************************************************************************/

/* Remove a user from the IRC network.  `source' is the nick which should
 * generate the kill, or NULL for a server-generated kill.
 */

void kill_user(const char *source, const char *user, const char *reason)
{
    char *av[2];
    char buf[BUFSIZE];

    if (!user || !*user)
	return;
    if (!source || !*source)
	source = ServerName;
    if (!reason)
	reason = "";
    snprintf(buf, sizeof(buf), "%s (%s)", source, reason);
    av[0] = sstrdup(user);
    av[1] = buf;
    send_cmd(source, "KILL %s :%s", user, av[1]);
    do_kill(source, 2, av);
    free(av[0]);
}

/*************************************************************************/

/* Note a bad password attempt for the given user.  If they've used up
 * their limit, toss them off.
 */

void bad_password(User *u)
{
    time_t now = time(NULL);

    if (!BadPassLimit)
	return;

    if (BadPassTimeout > 0 && u->invalid_pw_time > 0
			&& u->invalid_pw_time < now - BadPassTimeout)
	u->invalid_pw_count = 0;
    u->invalid_pw_count++;
    u->invalid_pw_time = now;
    if (u->invalid_pw_count >= BadPassLimit)
#ifdef IRC_BAHAMUT
	send_cmd(NULL, "SVSKILL %s :%s", u->nick, "Too many invalid passwords");
#else
	kill_user(NULL, u->nick, "Too many invalid passwords");
#endif
}

/*************************************************************************/
